@@ -1,5 +1,5 @@
 package Mira::CLI::Command::init;
-$Mira::CLI::Command::init::VERSION = '0.07';
+$Mira::CLI::Command::init::VERSION = '00.07.22';
 
 use strict;
 use warnings;
@@ -45,6 +45,7 @@ sub execute {
   my $pensource = $opt->{directory};
 
   {
+my $user = $ENV{'USER'} ? $ENV{'USER'} : 'YOUR_USER_NAME';
   my $config_file = <<"EOCF";
 
 #general 'mira' config, you can make config files for any floor in /config/FLOOR_NAME.yml
@@ -53,9 +54,14 @@ sub execute {
 title: Your Site Tilte
 description: Description of your site
 
-author: $ENV{USER}
+author: $user
 email: your-email\@domain.com
 
+# each field you make here, like github and...
+# is available in template: {{ MAIN.github }}
+github: https://www.github.com/Your_GitHub_NAME
+
+
  # the base hostname & protocol for your site
 url: http://localhost:80
 root: /
@@ -69,7 +75,7 @@ permalink: :year/:month/:day/:title/
 #TimeZone: +00:00
 
 ## Build settings
-default_body_format: markdown
+default_markup: markdown
 
 ## number of posts will be show in main index page
 post_num: 3
@@ -80,15 +86,12 @@ archive_post_num: 10
 ## if create new entry without --floor switch, mira use this field
 default_floor: blog
 
-## Mira's main directory in your pc
-penurl: $pensource
-
 
 ## template path by root is penurlPATH/template
 ## if you want use a custom template for examle in penurlPATH/template/CustomThEM
 ## just type custom template folder name
 #> template: Custom_Template_Folde_Name
-template: mira-theme-rtl
+template: default-theme
 
 ## the fields you want use for archive, like category, tag and ...
 ## by default Mira archive date field dont need type it here
@@ -97,19 +100,42 @@ template: mira-theme-rtl
 
 #this fields are not allowed: archives, static
 lists:
+  - date
   - categories
   - tags
   - author
 
 #url address for long keys or unicode which you want make latin addres for'em
 # for example if you have 'longcategoryname' you can make /category/lcn
-namespace:
-  veryverylongarchivename : vlan
-  آموزش: learn
-  کتاب: book
-  درباره: about
-  شخصی: personal
-  ترمینال: terminal
+#namespace:
+#  veryverylongarchivename : vlan
+#  learnsections: learn
+#  mybooksButWithALongname: book
+#  aboutThisSite: about
+#  myPersonalDailyDiary: personal
+#  terminalCommandLearning: terminal
+
+social:
+ -  icon: twitter
+    url: https://twitter.com/Twitter_UserName
+    desc: Follow me on twitter
+    share_url: http://twitter.com/share
+    share_title: ?text=
+    share_link: "&amp;url="
+
+ -  icon: github
+    url: https://github.com/GitHub_UserName
+    desc: Fork me on github
+    share_url:
+    share_title:
+    share_link:
+
+ -  icon: instagram
+    url: https://instagram.com/NAME
+    desc: Follow me
+    share_url:
+    share_title:
+    share_link:
 
 EOCF
 
@@ -122,6 +148,7 @@ EOCF
 
   make_path catdir($pensource,"content");
   make_path catdir($pensource,"content","blog");
+  make_path catdir($pensource,"config");
 
   my $sharedir = dist_dir('Mira');
 
